@@ -55,7 +55,7 @@ class DistributedScheduler(object):
     extract = None  # the tld extractor
     hits = 0  # default number of hits for a queue
     window = 0  # default window to calculate number of hits
-    my_ip = None  # the ip address of the scheduler (if needed)
+    my_ip = '127.0.0.1'  # the ip address of the scheduler (if needed)
     old_ip = None  # the old ip for logging
     signals = None  # scrapy signals
     ip_update_interval = 0  # the interval to update the ip address
